create temporary table pgdump_restore_path(p text);
--
-- NOTE:
--
-- File paths need to be edited. Search for $$PATH$$ and
-- replace it with the path to the directory containing
-- the extracted data files.
--
-- Edit the following to match the path where the
-- tar archive has been extracted.
--
insert into pgdump_restore_path values('/tmp');

--
-- PostgreSQL database dump
--

SET client_encoding = 'SQL_ASCII';
SET standard_conforming_strings = off;
SET check_function_bodies = false;
SET client_min_messages = warning;
SET escape_string_warning = off;

SET search_path = public, pg_catalog;

DROP TRIGGER insert_update_data ON public.data;
DROP TRIGGER insert_nodes ON public.nodes;
DROP TRIGGER delete_nodes ON public.nodes;
DROP INDEX public.metadata_idx;
DROP INDEX public.data_idx;
ALTER TABLE ONLY public.nodes DROP CONSTRAINT nodes_pkey;
ALTER TABLE ONLY public.main DROP CONSTRAINT main_pkey;
ALTER TABLE ONLY public.main DROP CONSTRAINT main_key_key;
ALTER TABLE public.nodes ALTER COLUMN node_id DROP DEFAULT;
ALTER TABLE public.main ALTER COLUMN id DROP DEFAULT;
DROP SEQUENCE public.nodes_node_id_seq;
DROP TABLE public.nodes;
DROP TABLE public.metadata;
DROP SEQUENCE public.main_id_seq;
DROP TABLE public.main;
DROP TABLE public.data;
DROP FUNCTION public."match"(character varying, character varying);
DROP FUNCTION public.insert_update_data_trigger_proc();
DROP FUNCTION public.insert_nodes_trigger_proc();
DROP FUNCTION public.delete_nodes_trigger_proc();
DROP PROCEDURAL LANGUAGE plpythonu;
DROP PROCEDURAL LANGUAGE plpgsql;
DROP SCHEMA public;
--
-- Name: public; Type: SCHEMA; Schema: -; Owner: postgres
--

CREATE SCHEMA public;


ALTER SCHEMA public OWNER TO postgres;

--
-- Name: SCHEMA public; Type: COMMENT; Schema: -; Owner: postgres
--

COMMENT ON SCHEMA public IS 'Standard public schema';


--
-- Name: plpgsql; Type: PROCEDURAL LANGUAGE; Schema: -; Owner: postgres
--

CREATE PROCEDURAL LANGUAGE plpgsql;


--
-- Name: plpythonu; Type: PROCEDURAL LANGUAGE; Schema: -; Owner: postgres
--

CREATE PROCEDURAL LANGUAGE plpythonu;


--
-- Name: delete_nodes_trigger_proc(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION delete_nodes_trigger_proc() RETURNS "trigger"
    AS $$
BEGIN
DELETE FROM metadata WHERE OLD.node_id = node_id;
UPDATE metadata set metavalue = CURRENT_TIMESTAMP
		WHERE OLD.parent_id = node_id AND metakey = 'utime';
RETURN OLD;
END;
$$
    LANGUAGE plpgsql;


ALTER FUNCTION public.delete_nodes_trigger_proc() OWNER TO postgres;

--
-- Name: insert_nodes_trigger_proc(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION insert_nodes_trigger_proc() RETURNS "trigger"
    AS $$
BEGIN
	INSERT INTO metadata(node_id, metakey, metavalue, is_vector)
		VALUES(new.node_id, 'ctime', CURRENT_TIMESTAMP, 0);
	INSERT INTO metadata(node_id, metakey, metavalue, is_vector)
		VALUES(new.node_id, 'utime', CURRENT_TIMESTAMP, 0);
	UPDATE metadata set metavalue = CURRENT_TIMESTAMP
		WHERE new.parent_id = node_id AND metakey = 'utime';
    RETURN new;
END;
$$
    LANGUAGE plpgsql;


ALTER FUNCTION public.insert_nodes_trigger_proc() OWNER TO postgres;

--
-- Name: insert_update_data_trigger_proc(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION insert_update_data_trigger_proc() RETURNS "trigger"
    AS $$
    BEGIN
	UPDATE metadata set metavalue = CURRENT_TIMESTAMP
		WHERE new.node_id = node_id AND metakey = 'utime';
    RETURN new;
    END;
$$
    LANGUAGE plpgsql;


ALTER FUNCTION public.insert_update_data_trigger_proc() OWNER TO postgres;

--
-- Name: match(character varying, character varying); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION "match"(character varying, character varying) RETURNS boolean
    AS $$
    import re
    if (SD.has_key(args[0]) == False):
        SD[args[0]] = re.compile(args[0])
    return SD[args[0]].match(args[1]) != None
$$
    LANGUAGE plpythonu;


ALTER FUNCTION public."match"(character varying, character varying) OWNER TO postgres;

SET default_tablespace = '';

SET default_with_oids = false;

--
-- Name: data; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE data (
    node_id integer NOT NULL,
    filename character varying NOT NULL
);


ALTER TABLE public.data OWNER TO postgres;

--
-- Name: main; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE main (
    id integer NOT NULL,
    "key" character varying(32) NOT NULL,
    value character varying(128)
);


ALTER TABLE public.main OWNER TO postgres;

--
-- Name: main_id_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE main_id_seq
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 1;


ALTER TABLE public.main_id_seq OWNER TO postgres;

--
-- Name: main_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: postgres
--

ALTER SEQUENCE main_id_seq OWNED BY main.id;


--
-- Name: main_id_seq; Type: SEQUENCE SET; Schema: public; Owner: postgres
--

SELECT pg_catalog.setval('main_id_seq', 2, true);


--
-- Name: metadata; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE metadata (
    node_id integer NOT NULL,
    metakey character varying(50) NOT NULL,
    metavalue character varying(128) NOT NULL,
    is_vector integer DEFAULT 0 NOT NULL
);


ALTER TABLE public.metadata OWNER TO postgres;

--
-- Name: nodes; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE nodes (
    node_id integer NOT NULL,
    node_name character varying NOT NULL,
    parent_id integer NOT NULL,
    is_directory integer DEFAULT 0 NOT NULL
);


ALTER TABLE public.nodes OWNER TO postgres;

--
-- Name: nodes_node_id_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE nodes_node_id_seq
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 1;


ALTER TABLE public.nodes_node_id_seq OWNER TO postgres;

--
-- Name: nodes_node_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: postgres
--

ALTER SEQUENCE nodes_node_id_seq OWNED BY nodes.node_id;


--
-- Name: nodes_node_id_seq; Type: SEQUENCE SET; Schema: public; Owner: postgres
--

SELECT pg_catalog.setval('nodes_node_id_seq', 70, true);


--
-- Name: id; Type: DEFAULT; Schema: public; Owner: postgres
--

ALTER TABLE main ALTER COLUMN id SET DEFAULT nextval('main_id_seq'::regclass);


--
-- Name: node_id; Type: DEFAULT; Schema: public; Owner: postgres
--

ALTER TABLE nodes ALTER COLUMN node_id SET DEFAULT nextval('nodes_node_id_seq'::regclass);


--
-- Data for Name: data; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY data (node_id, filename) FROM stdin;
\.
copy data (node_id, filename)  from '$$PATH$$/1630.dat' ;
--
-- Data for Name: main; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY main (id, "key", value) FROM stdin;
\.
copy main (id, "key", value)  from '$$PATH$$/1631.dat' ;
--
-- Data for Name: metadata; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY metadata (node_id, metakey, metavalue, is_vector) FROM stdin;
\.
copy metadata (node_id, metakey, metavalue, is_vector)  from '$$PATH$$/1633.dat' ;
--
-- Data for Name: nodes; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY nodes (node_id, node_name, parent_id, is_directory) FROM stdin;
\.
copy nodes (node_id, node_name, parent_id, is_directory)  from '$$PATH$$/1632.dat' ;
--
-- Name: main_key_key; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY main
    ADD CONSTRAINT main_key_key UNIQUE ("key");


--
-- Name: main_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY main
    ADD CONSTRAINT main_pkey PRIMARY KEY (id);


--
-- Name: nodes_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace: 
--

ALTER TABLE ONLY nodes
    ADD CONSTRAINT nodes_pkey PRIMARY KEY (node_id);


--
-- Name: data_idx; Type: INDEX; Schema: public; Owner: postgres; Tablespace: 
--

CREATE INDEX data_idx ON data USING btree (node_id);


--
-- Name: metadata_idx; Type: INDEX; Schema: public; Owner: postgres; Tablespace: 
--

CREATE INDEX metadata_idx ON metadata USING btree (node_id);


--
-- Name: delete_nodes; Type: TRIGGER; Schema: public; Owner: postgres
--

CREATE TRIGGER delete_nodes
    BEFORE DELETE ON nodes
    FOR EACH ROW
    EXECUTE PROCEDURE delete_nodes_trigger_proc();


--
-- Name: insert_nodes; Type: TRIGGER; Schema: public; Owner: postgres
--

CREATE TRIGGER insert_nodes
    AFTER INSERT ON nodes
    FOR EACH ROW
    EXECUTE PROCEDURE insert_nodes_trigger_proc();


--
-- Name: insert_update_data; Type: TRIGGER; Schema: public; Owner: postgres
--

CREATE TRIGGER insert_update_data
    AFTER INSERT OR UPDATE ON data
    FOR EACH ROW
    EXECUTE PROCEDURE insert_update_data_trigger_proc();


--
-- Name: public; Type: ACL; Schema: -; Owner: postgres
--

REVOKE ALL ON SCHEMA public FROM PUBLIC;
REVOKE ALL ON SCHEMA public FROM postgres;
GRANT ALL ON SCHEMA public TO postgres;
GRANT ALL ON SCHEMA public TO PUBLIC;
GRANT ALL ON SCHEMA public TO "SAGA";


--
-- Name: insert_nodes_trigger_proc(); Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON FUNCTION insert_nodes_trigger_proc() FROM PUBLIC;
REVOKE ALL ON FUNCTION insert_nodes_trigger_proc() FROM postgres;
GRANT ALL ON FUNCTION insert_nodes_trigger_proc() TO postgres;
GRANT ALL ON FUNCTION insert_nodes_trigger_proc() TO PUBLIC;


--
-- Name: insert_update_data_trigger_proc(); Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON FUNCTION insert_update_data_trigger_proc() FROM PUBLIC;
REVOKE ALL ON FUNCTION insert_update_data_trigger_proc() FROM postgres;
GRANT ALL ON FUNCTION insert_update_data_trigger_proc() TO postgres;
GRANT ALL ON FUNCTION insert_update_data_trigger_proc() TO PUBLIC;


--
-- Name: match(character varying, character varying); Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON FUNCTION "match"(character varying, character varying) FROM PUBLIC;
REVOKE ALL ON FUNCTION "match"(character varying, character varying) FROM postgres;
GRANT ALL ON FUNCTION "match"(character varying, character varying) TO postgres;
GRANT ALL ON FUNCTION "match"(character varying, character varying) TO PUBLIC;
GRANT ALL ON FUNCTION "match"(character varying, character varying) TO "SAGA";


--
-- Name: data; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE data FROM PUBLIC;
REVOKE ALL ON TABLE data FROM postgres;
GRANT ALL ON TABLE data TO postgres;
GRANT ALL ON TABLE data TO "SAGA";


--
-- Name: main; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE main FROM PUBLIC;
REVOKE ALL ON TABLE main FROM postgres;
GRANT ALL ON TABLE main TO postgres;
GRANT ALL ON TABLE main TO "SAGA";


--
-- Name: main_id_seq; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON SEQUENCE main_id_seq FROM PUBLIC;
REVOKE ALL ON SEQUENCE main_id_seq FROM postgres;
GRANT ALL ON SEQUENCE main_id_seq TO postgres;
GRANT SELECT,UPDATE ON SEQUENCE main_id_seq TO "SAGA";


--
-- Name: metadata; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE metadata FROM PUBLIC;
REVOKE ALL ON TABLE metadata FROM postgres;
GRANT ALL ON TABLE metadata TO postgres;
GRANT ALL ON TABLE metadata TO "SAGA";


--
-- Name: nodes; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE nodes FROM PUBLIC;
REVOKE ALL ON TABLE nodes FROM postgres;
GRANT ALL ON TABLE nodes TO postgres;
GRANT ALL ON TABLE nodes TO "SAGA";


--
-- Name: nodes_node_id_seq; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON SEQUENCE nodes_node_id_seq FROM PUBLIC;
REVOKE ALL ON SEQUENCE nodes_node_id_seq FROM postgres;
GRANT ALL ON SEQUENCE nodes_node_id_seq TO postgres;
GRANT SELECT,UPDATE ON SEQUENCE nodes_node_id_seq TO "SAGA";


--
-- PostgreSQL database dump complete
--

